@@ -7,7 +7,6 @@ from typing import Dict, Any
 from jamstats.data.game_data import DerbyGame
 import logging
 import seaborn as sns
-import pkg_resources
 
 logger = logging.Logger(__name__)
 
@@ -24,26 +23,29 @@ def load_json_derby_game(game_json) -> DerbyGame:
     Returns:
         DerbyGame: derby game
     """
+    logger.debug("load_json_derby_game start.")
     # this combo is inefficient
     json_major_version = get_json_major_version(game_json["state"])
     json_version = get_json_version(game_json["state"])
 
+    logger.debug("Loading game data")
     pdf_game_state = json_to_game_dataframe(game_json)
     game_data_dict = extract_game_data_dict(pdf_game_state)
     game_data_dict["scoreboard_version"] = json_version
-    game_data_dict["jamstats_version"] = pkg_resources.require("jamstats")[0].version
 
+    logger.debug("Extracting roster")
     pdf_roster = extract_roster(pdf_game_state,
                                 game_data_dict["team_1"],
                                 game_data_dict["team_2"])
+    logger.debug("Extracting jam data")
     pdf_game_data = extract_jam_data(pdf_game_state, pdf_roster)
+    logger.debug("Extracting penalties")
     pdf_penalties = extract_penalties(pdf_game_state, pdf_roster,
                                       json_major_version)
     try:
         pdf_team_colors = extract_team_colors(pdf_game_state)
     except Exception as e:
         logger.warn(f"Failed to extract team colors. Exception: {e}")
-
     return DerbyGame(pdf_game_data, game_data_dict, pdf_penalties, pdf_team_colors)
 
 
@@ -69,8 +71,7 @@ def json_to_game_dataframe(game_json: Dict[Any, Any]) -> pd.DataFrame:
         # In-process games have both "CurrentGame" fields and fields
         # annotated with a game identifier. Complete games don't have
         # "CurrentGame" fields.
-        # I believe the "CurrentGame" fields are the ones I want,
-        # for in-process games. Strip out the others.
+        # I think the "CurrentGame" fields are junk. Get rid of them.
         logger.debug(f"Found version 5. Checking for in-progress game...")
         is_in_progress_game = False
         for key in game_dict:
@@ -79,11 +80,11 @@ def json_to_game_dataframe(game_json: Dict[Any, Any]) -> pd.DataFrame:
                break
         if is_in_progress_game:
             logger.debug(f"Found in-progress game. Stripping rows. Before: {len(game_dict)} keys")
-            game_dict_new = {}
-            for key in game_dict:
-                if not key.split(".")[1].startswith("Game("):
-                    game_dict_new[key.replace("CurrentGame", "Game(dummy)")] = game_dict[key]
-            game_dict = game_dict_new
+            game_dict_new = {
+                key: game_dict[key]
+                for key in game_dict
+                if not key.split(".")[1] == "CurrentGame"
+            }
             logger.debug(f"After: {len(game_dict)} keys.")
         game_dict_new = {
             ".".join([chunk for chunk in key.split(".") if not chunk.startswith("Game(")]):
@@ -500,6 +501,14 @@ def extract_team_perjam_skaters(pdf_ateamjams_data: pd.DataFrame,
     logger.debug(f"    Before roster merge, team jam skater data: {len(pdf_ateamjams_data_skaters)}")
     pdf_ateamjams_data_skaters_withname = pdf_ateamjams_data_skaters.merge(
         pdf_roster, on="Id")
+    # Sometimes, we're unable to get proper roster data, e.g., for an in-progress game.
+    # In that case, merging back to the roster gives us nothing.
+    # Let's limp along with a left join so we can show most of the plots.
+    if len(pdf_ateamjams_data_skaters_withname) == 0:
+        pdf_ateamjams_data_skaters_withname = pdf_ateamjams_data_skaters.merge(
+            pdf_roster, on="Id", how="left")
+        logger.warn("Failed to join skater data with roster. Merged with left join, "
+                    f"rows {len(pdf_ateamjams_data_skaters_withname)}")
     logger.debug(f"    After roster merge, team jam skater data: {len(pdf_ateamjams_data_skaters_withname)}")
 
     pdf_jam_skater_lists = pdf_ateamjams_data_skaters_withname.groupby(
